@@ -20,13 +20,16 @@
 #'
 #' @param outdata An `outdata` object created by [format_ae_forestly()].
 #' @param display_soc_toggle A boolean value to display SOC toggle button.
+#' @param display_diff_toggle A boolean value to display risk difference toggle button.
 #' @param filter A character value of the filter variable.
 #' @param filter_label A character value of the label for slider bar.
 #' @param filter_range A numeric vector of length 2 for the range of the slider bar.
+#' @param ae_label A character value of the label for criteria.
 #'   If NULL (default), the range is automatically calculated from the data.
 #'   If only one value is provided, it will be used as the maximum and minimum will be 0.
 #' @param width A numeric value of width of the table in pixels.
 #' @param max_page A numeric value of max page number shown in the table.
+#' @param dowload_button A logical value to display download button.
 #'
 #' @return An AE forest plot saved as a `shiny.tag.list` object.
 #'
@@ -46,11 +49,14 @@
 #' }
 ae_forestly <- function(outdata,
                         display_soc_toggle = TRUE,
+                        display_diff_toggle = FALSE,
                         filter = c("prop", "n"),
                         filter_label = NULL,
                         filter_range = NULL,
+                        ae_label = NULL,
                         width = 1400,
-                        max_page = NULL) {
+                        max_page = NULL,
+                        dowload_button = FALSE) {
   filter <- match.arg(filter)
 
   # Handle filter_range parameter
@@ -89,8 +95,8 @@ ae_forestly <- function(outdata,
 
   if (is.null(filter_label)) {
     filter_label <- ifelse(filter == "prop",
-      "Incidence (%) in One or More Treatment Groups",
-      "Number of AE in One or More Treatment Groups"
+                           "Incidence (%) in One or More Treatment Groups",
+                           "Number of AE in One or More Treatment Groups"
     )
   }
 
@@ -104,8 +110,8 @@ ae_forestly <- function(outdata,
 
   parameters <- unlist(strsplit(outdata$parameter, ";"))
   par_label <- vapply(parameters,
-    function(x) metalite::collect_adam_mapping(outdata$meta, x)$label,
-    FUN.VALUE = character(1)
+                      function(x) metalite::collect_adam_mapping(outdata$meta, x)$label,
+                      FUN.VALUE = character(1)
   )
 
   for (par in parameters[(!(parameters %in% unique(outdata$parameter_order)))]) {
@@ -136,9 +142,14 @@ ae_forestly <- function(outdata,
   default_param <- as.character(unique(outdata$tbl$parameter)[1])
 
   random_id <- paste0("filter_ae_", uuid::UUIDgenerate(), "|", default_param)
+
+  if (is.null(ae_label)) {
+    ae_label <- "AE Criteria"
+  }
+
   filter_ae <- crosstalk::filter_select(
     id = random_id,
-    label = "AE Criteria",
+    label = ae_label,
     sharedData = tbl,
     group = ~parameter,
     multiple = FALSE
@@ -177,13 +188,31 @@ ae_forestly <- function(outdata,
   filter_subject$children[[2]]$attribs$`data-to` <- filter_range[2]
   filter_subject$children[[2]]$attribs$`data-max` <- filter_range[2]
 
+  diff_cols <- c(
+    names(outdata$diff)
+  )
+
+  all_diff_cols <- c(diff_cols, "diff_fig")
+  displayed_diff_cols <- intersect(all_diff_cols, c(
+    if ("diff" %in% outdata$display) diff_cols else NULL,
+    if ("fig_diff" %in% outdata$display) "diff_fig" else NULL
+  ))
+
+  hidden_cols <- outdata$hidden_column
+  if (display_diff_toggle) {
+    hidden_cols <- setdiff(hidden_cols, displayed_diff_cols)
+  }
+
   p_reactable <- reactable2(
     tbl,
     columns = outdata$reactable_columns,
     columnGroups = outdata$reactable_columns_group,
-    hidden_item = paste0("'", outdata$hidden_column, "'", collapse = ", "),
+    hidden_item = paste0("'", hidden_cols, "'", collapse = ", "),
     soc_toggle = display_soc_toggle,
+    diff_toggle = display_diff_toggle,
+    diff_columns = displayed_diff_cols,
     width = width,
+    download = dowload_button,
     searchable = FALSE,
     details = function(index) {
       t_row <- outdata$tbl$name[index]
@@ -192,9 +221,9 @@ ae_forestly <- function(outdata,
       t_details <- subset(
         outdata$ae_listing,
         ((toupper(outdata$ae_listing$Adverse_Event) %in% toupper(t_row)) &
-          (outdata$ae_listing$param == t_param)) |
+           (outdata$ae_listing$param == t_param)) |
           ((toupper(outdata$ae_listing$SOC_Name) %in% toupper(t_row)) &
-            (outdata$ae_listing$param == t_param))
+             (outdata$ae_listing$param == t_param))
       )
 
       # Exclude 'param' column from t_details
